@@ -344,13 +344,13 @@ func (t *Transformers) TransformExpr(expr Expression) Expression {
 				TargetType: expr.TypeAssertion.TargetType,
 			},
 		}
-	case ExpressionTypeCast:
+	case ExpressionTypeTypeCast:
 		out = Expression{
 			Type:           expr.Type,
 			ExpressionType: expr.ExpressionType,
-			Cast: &Cast{
-				Expression:   t.TransformExpr(expr.Cast.Expression),
-				TargetTypeID: expr.Cast.TargetTypeID,
+			TypeCast: &TypeCast{
+				Expression:   t.TransformExpr(expr.TypeCast.Expression),
+				TargetTypeID: expr.TypeCast.TargetTypeID,
 			},
 		}
 	case ExpressionTypeObjectFieldAccess:
